Dummy Sample Output
===================

.. code-block:: json

    {
       "hypervisor": "xen"
       "failed": false,
       "changed": true,
       "hosts": [
          dummy-8c8b6b-0,
          dummy-8c8b6b-1,
          dummy-8c8b6b-2,
      ],
       "resource_type": "dummy_res",
       "dummy_file": "/tmp/dummy.hosts"
    }
